"""Live tests for IDSite functionality."""


from uuid import uuid4

from .base import AuthenticatedLiveBase
from stormpath.resources.id_site import IDSite, IDSiteList
from stormpath.resources.tenant import Tenant


class TestIDSite(AuthenticatedLiveBase):

    def test_id_site_collection_contains_single_idsite(self):
        self.assertEqual(len(self.client.tenant.id_sites), 1)

    def test_id_site_is_id_site_resource(self):
        self.assertIsInstance(self.client.tenant.id_sites, IDSiteList)
        self.assertIsInstance(self.client.tenant.id_sites[0], IDSite)

    def test_id_site_attributes_can_be_written(self):
        id_site = self.client.tenant.id_sites[0]
        domain_name = uuid4().hex + '.example.com'

        id_site.domain_name = domain_name
        id_site.tls_public_cert = 'hi'
        id_site.tls_private_key = 'hi'
        id_site.git_repo_url = 'https://github.com/stormpath/stormpath-sdk-python.git'
        id_site.git_branch = 'master'
        id_site.authorized_origin_uris = ['https://hi.com']
        id_site.authorized_redirect_uris = ['https://hi.com']
        id_site.logo_url = 'https://hi.com/woot.jpg'
        id_site.session_tti = 'P1D'
        id_site.session_ttl = 'P1D'
        id_site.session_cookie_persistent = True

        id_site.save()
        id_site = self.client.tenant.id_sites[0]
        id_site.refresh()

        self.assertEqual(id_site.domain_name, domain_name)
        self.assertEqual(id_site.tls_public_cert, 'hi')
        self.assertEqual(id_site.tls_private_key, 'hi')
        self.assertEqual(id_site.git_repo_url, 'https://github.com/stormpath/stormpath-sdk-python.git')
        self.assertEqual(id_site.git_branch, 'master')
        self.assertEqual(id_site.authorized_origin_uris, ['https://hi.com'])
        self.assertEqual(id_site.authorized_redirect_uris, ['https://hi.com'])
        self.assertEqual(id_site.logo_url, 'https://hi.com/woot.jpg')
        self.assertEqual(id_site.session_tti, 'P1D')
        self.assertEqual(id_site.session_ttl, 'P1D')
        self.assertEqual(id_site.session_cookie_persistent, True)

    def test_id_site_tenant(self):
        id_site = self.client.tenant.id_sites[0]
        self.assertIsInstance(id_site.tenant, Tenant)
